@@ -141,6 +141,7 @@ void SetSpeed(int control)
 	int s1;
 	int wpm;
 	int wpm2;
+	int wpm_value;
 	double sonic;
 
 	speed.loud_consonants = 0;
@@ -153,6 +154,8 @@ void SetSpeed(int control)
 	if(control == 2)
 		wpm = embedded_value[EMBED_S2];
 
+	wpm_value = wpm;
+
 	if(voice->speed_percent > 0)
 	{
 		wpm = (wpm * voice->speed_percent)/100;
@@ -162,7 +165,7 @@ void SetSpeed(int control)
 	{
 		DoSonicSpeed(1 * 1024);
 	}
-	if((wpm > 450) || ((wpm > speed.fast_settings[0]) && (wpm > 350)))
+	if((wpm_value > 450) || ((wpm_value > speed.fast_settings[0]) && (wpm > 350)))
 	{
 		wpm2 = wpm;
 		wpm = 175;
@@ -712,14 +715,14 @@ if(stress <= 1)
 			if(stress >= 7)
 			{
 				// tonic syllable, include a constant component so it doesn't decrease directly with speed
-				length_mod += 20;
+				length_mod += tr->langopts.lengthen_tonic;
 				if(emphasized)
-					length_mod += 10;
+					length_mod += (tr->langopts.lengthen_tonic/2);
 			}
 			else
 			if(emphasized)
 			{
-				length_mod += 20;
+				length_mod += tr->langopts.lengthen_tonic;
 			}
 
 			if((len = tr->stress_lengths[stress]) == 0)
@@ -736,7 +739,8 @@ if(stress <= 1)
 				}
 			}
 
-			if(end_of_clause == 2)
+
+			if((end_of_clause == 2) && !(tr->langopts.stress_flags & S_NO_EOC_LENGTHEN))
 			{
 				// this is the last syllable in the clause, lengthen it - more for short vowels
 				len = (p->ph->std_length * 2);
