@@ -35,8 +35,8 @@
 #include "translate.h"
 #include "wave.h"
 
-const char *version_string = "1.45.30  10.Jun.11";
-const int version_phdata  = 0x014500;
+const char *version_string = "1.46.11  24.Dec.11";
+const int version_phdata  = 0x014600;
 
 int option_device_number = -1;
 FILE *f_logespeak = NULL;
@@ -172,9 +172,11 @@ void FreePhData(void)
 	Free(phoneme_tab_data);
 	Free(phoneme_index);
 	Free(phondata_ptr);
+	Free(tunes);
 	phoneme_tab_data=NULL;
 	phoneme_index=NULL;
 	phondata_ptr=NULL;
+	tunes=NULL;
 }
 
 
@@ -512,6 +514,7 @@ void LoadConfig(void)
 			}
 		}
 	}
+	fclose(f);
 }  //  end of LoadConfig
 
 
@@ -612,7 +615,16 @@ static bool InterpretCondition(Translator *tr, int control, PHONEME_LIST *plist,
 	int count;
 	PHONEME_TAB *ph;
 	PHONEME_LIST *plist_this;
-	static int ph_position[8] = {0, 1, 2, 3, 2, 0, 1, 3};  // prevPh, thisPh, nextPh, next2Ph, nextPhW, prevPhW, nextVowel, next2PhW
+	static int ph_position[8] = {0, 1, 2, 3, 2, 0, 1, 3};  // prevPh, thisPh, nextPh, next2Ph, nextPhW, prevPhW, nextVowel, (other conditions)
+
+	// instruction: 2xxx, 3xxx
+
+	// bits 8-10 = 0 to 6,  which phoneme
+	// bit 11 = 0, bits 0-7 are a phoneme code
+	// bit 11 = 1, bits 5-7 type of data, bits 0-4 data value
+
+	// bits 8-10 = 7,  other conditions
+
 
 	data = instn & 0xff;
 	instn2 = instn >> 8;
@@ -633,13 +645,6 @@ static bool InterpretCondition(Translator *tr, int control, PHONEME_LIST *plist,
 			if(plist[0].sourceix)
 				return(false);
 		}
-		if(which==7)
-		{
-			// nextPh2 not word boundary
-			if((plist[1].sourceix) || (plist[2].sourceix))
-				return(false);
-		}
-
 		if(which==6)
 		{
 			// nextVowel, not word boundary
@@ -670,7 +675,7 @@ static bool InterpretCondition(Translator *tr, int control, PHONEME_LIST *plist,
 
 		if(control & 0x100)
 		{
-			// change phonemes pass
+			// "change phonemes" pass
 			plist->ph = phoneme_tab[plist->phcode];
 		}
 		ph = plist->ph;
@@ -782,6 +787,9 @@ static bool InterpretCondition(Translator *tr, int control, PHONEME_LIST *plist,
 						break;
 				}
 				return(count > 0);
+
+			case 0x10:  //  isTranslationGiven
+				return((plist->synthflags & SFLAG_DICTIONARY) != 0);
 			}
 			break;
 
@@ -902,7 +910,7 @@ void InterpretPhoneme(Translator *tr, int control, PHONEME_LIST *plist, PHONEME_
 		
 		switch(instn >> 12)
 		{
-		case 0:
+		case 0:   // 0xxx
 			data = instn & 0xff;
 
 			if(instn2 == 0)
